# CPList

A CPython parser/serializer for Apple's PropertyList format, using [libplist](https://github.com/libimobiledevice/libplist), with improved performance over Python's standard library `plistlib`.


## Why?
This is around 3-4x faster than CPython's PList implementation.

## Bugs

None so far

